Configuring the timetable display
=================================

Some display options can be changed by the user, under `Account → Settings → Timetables`:

* **Shorten groups in timetable views**: With this setting activated, lists
  with more groups than set in the system-wide limit will be collapsed into
  a shorter string (e.g. 5a,b,c,d,e,f might be abbreviated as 5a-f)
